<?php
namespace AIOSEO\Plugin\Extend\Schema\Graphs;

use AIOSEO\Plugin\Common\Schema\Graphs as CommonGraphs;

/**
 * LocalBusiness graph class.
 *
 * @since 1.0.0
 */
class LocalBusiness extends CommonGraphs\Graph {

	/**
	 * Returns the graph data.
	 *
	 * @since 1.0.0
	 *
	 * @return array The graph data.
	 */
	public function get() {
		/* if ( is_singular() ) {
			$post = get_post();
			if ( ! $post || 'aioseo-location' !== $post->post_type ) {
				return [];
			}
			$post = Models\Post::getPost( $post->ID );
			if ( ! $post || ! $post->location ) {
				return [];
			}
			$this->meta = array_filters( json_decode( $post->location ) );
			if ( ! $this->meta ) {
				return [];
			}
		} */

		$data = [
			'@type'                     => $this->businessType(),
			'@id'                       => trailingslashit( home_url() ) . '#localbusiness',
			'name'                      => $this->name(),
			'brand'                     => [
				'@id' => trailingslashit( home_url() ) . '#organization'
			],
			'url'                       => trailingslashit( home_url() ),
			'image'                     => $this->businessImage(),
			'logo'                      => trailingslashit( home_url() ) . '#logo',
			'address'                   => $this->address(),
			'email'                     => aioseo()->options->localBusiness->locations->business->contact->email,
			'telephone'                 => $this->phoneNumber(),
			'faxNumber'                 => aioseo()->options->localBusiness->locations->business->contact->fax,
			'priceRange'                => aioseo()->options->localBusiness->locations->business->payment->priceRange,
			'currenciesAccepted'        => $this->acceptedCurrencies(),
			'paymentAccepted'           => aioseo()->options->localBusiness->locations->business->payment->methods,
			'areaServed'                => aioseo()->options->localBusiness->locations->business->areaServed,
			'taxID'                     => aioseo()->options->localBusiness->locations->business->ids->tax,
			'vatID'                     => aioseo()->options->localBusiness->locations->business->ids->vat,
			'openingHoursSpecification' => $this->openingHours()
		];

		if ( $data['address'] ) {
			$data['location'] = [
				'@id' => trailingslashit( home_url() ) . '#postaladdress'
			];
		}
		return $data;
	}

	/**
	 * Returns the business type.
	 *
	 * @since 1.0.0
	 *
	 * @return string $businessType The business type.
	 */
	private function businessType() {
		$businessType = aioseo()->options->localBusiness->locations->business->businessType;
		if ( ! $businessType ) {
			$businessType = 'LocalBusiness';
		}
		return $businessType;
	}

	/**
	 * Returns the name.
	 *
	 * @since 1.0.0
	 *
	 * @return string $name The name.
	 */
	private function name() {
		$name = aioseo()->options->localBusiness->locations->business->name;
		if ( $name ) {
			return $name;
		}
		$name = aioseo()->options->searchAppearance->global->schema->organizationName;
		if ( $name ) {
			return $name;
		}
		return aioseo()->helpers->decodeHtmlEntities( get_bloginfo( 'name' ) );
	}

	/**
	 * Returns the image.
	 *
	 * @since 1.0.0
	 *
	 * @return string $image The image.
	 */
	private function businessImage() {
		$image = aioseo()->options->localBusiness->locations->business->image;
		if ( $image ) {
			return $image;
		}
		// Fallback to Organization Logo.
		$image = aioseo()->options->searchAppearance->global->schema->organizationLogo;
		if ( $image ) {
			return $image;
		}
		// Fallback to Site Logo.
		return aioseo()->helpers->getSiteLogoUrl();
	}

	/**
	 * Returns the address.
	 *
	 * @since 1.0.0
	 *
	 * @return string $address The address.
	 */
	private function address() {
		if (
			! aioseo()->options->localBusiness->locations->business->address->streetLine1 &&
			! aioseo()->options->localBusiness->locations->business->address->streetLine2
		) {
			return [];
		}

		return [
			'@id'             => trailingslashit( home_url() ) . '#postaladdress',
			'@type'           => 'PostalAddress',
			'streetAddress'   => sprintf(
				'%1$s, %2$s',
				aioseo()->options->localBusiness->locations->business->address->streetLine1,
				aioseo()->options->localBusiness->locations->business->address->streetLine2
			),
			'postalCode'      => aioseo()->options->localBusiness->locations->business->address->zipCode,
			'addressLocality' => aioseo()->options->localBusiness->locations->business->address->city,
			'addressRegion'   => aioseo()->options->localBusiness->locations->business->address->state,
			'addressCountry'  => aioseo()->options->localBusiness->locations->business->address->country
		];
	}

	/**
	 * Returns the phone number.
	 *
	 * @since 1.0.0
	 *
	 * @return string $phoneNumber The phone number.
	 */
	private function phoneNumber() {
		$phoneNumber = aioseo()->options->localBusiness->locations->business->contact->phone;
		if ( $phoneNumber ) {
			return $phoneNumber;
		}
		// Fallback to Organization Phone.
		$phoneNumber = aioseo()->options->searchAppearance->global->schema->phone;
		if ( $phoneNumber ) {
			return $phoneNumber;
		}
		return false;
	}

	/**
	 * Returns the accepted currencies.
	 *
	 * @since 1.0.0
	 *
	 * @return string The accepted currencies as a string, separated by commas.
	 */
	private function acceptedCurrencies() {
		$currencies    = aioseo()->options->localBusiness->locations->business->payment->currenciesAccepted;
		$rawCurrencies = ! empty( $currencies ) ? json_decode( $currencies ) : $currencies;
		if ( ! $rawCurrencies ) {
			return '';
		}

		$currencies = [];
		foreach ( $rawCurrencies as $currency ) {
			$currencies[] = $currency->value;
		}
		return ! empty( $currencies ) ? implode( ', ', $currencies ) : '';
	}

	/**
	 * Returns the opening hours.
	 *
	 * @since 1.0.0
	 *
	 * @return array The opening hours.
	 */
	private function openingHours() {
		if ( ! aioseo()->options->localBusiness->openingHours->show ) {
			return [];
		}

		if ( aioseo()->options->localBusiness->openingHours->alwaysOpen ) {
			return [
				'@type'     => 'OpeningHoursSpecification',
				'dayOfWeek' => [
					'http://schema.org/Monday',
					'http://schema.org/Tuesday',
					'http://schema.org/Wednesday',
					'http://schema.org/Thursday',
					'http://schema.org/Friday',
					'http://schema.org/Saturday',
					'http://schema.org/Sunday'
				],
				'opens'     => '00:00',
				'closes'    => '23:59'
			];
		}

		$days = [];
		foreach ( aioseo()->options->localBusiness->openingHours->days->all() as $day => $values ) {
			if ( $values['closed'] ) {
				continue;
			}
			if ( $values['open24h'] ) {
				$days[] = [
					'@type'     => 'OpeningHoursSpecification',
					'dayOfWeek' => [
						'http://schema.org/' . ucfirst( $day )
					],
					'opens'     => '00:00',
					'closes'    => '23:59'
				];
				continue;
			}
			$days[] = [
				'@type'     => 'OpeningHoursSpecification',
				'dayOfWeek' => [
					'http://schema.org/' . ucfirst( $day )
				],
				'opens'     => $values['openTime'],
				'closes'    => $values['closeTime']
			];
		}
		return $days;
	}
}